@@ -5,8 +5,8 @@
 import datetime
 import os
 import shutil
-
-import git
+import stat
+import subprocess
 
 from quark import config
 from quark.utils.colors import green
@@ -18,6 +18,11 @@ CHECK_UP_TO_DATE = f"{config.HOME_DIR}.up_to_date.quark"
 SOURCE = "https://github.com/quark-engine/quark-rules"
 
 
+def set_rw(operation, name, exc):
+    os.chmod(name, stat.S_IWRITE)
+    return True
+
+
 def logger():
     """
     Write today's date into a file to record whether it has been updated on that day.
@@ -56,24 +61,33 @@ def download():
     :return: None
     """
     try:
-        git.Repo.clone_from(url=SOURCE, to_path=DIR_PATH)
+        result = subprocess.run(["git", "clone", "https://github.com/quark-engine/quark-rules", DIR_PATH],
+                                stdout=subprocess.PIPE,
+                                stderr=subprocess.PIPE)
 
-    except git.GitCommandError as error:
+        if result.returncode != 0:
+            # Download failed
+            dir_exists = "destination path"
+            network_unavailable = "unable to access"
 
-        dir_exists = "destination path"
-        network_unavailable = "unable to access"
+            if dir_exists in result.stderr.decode("utf-8"):
+                shutil.rmtree(DIR_PATH, onerror=set_rw)
+                download()
 
-        if dir_exists in error.stderr:
-            # remove the entire quark-rules directory and then clone again
-            shutil.rmtree(DIR_PATH)
-            download()
+            if network_unavailable in result.stderr.decode("utf-8"):
+                print_warning(
+                    f"Your network is currently unavailable, "
+                    f"you can use {green('freshquark')} "
+                    "to update the quark-rules later!\n"
+                )
 
-        if network_unavailable in error.stderr:
-            print_warning(
-                f"Your network is currently unavailable, "
-                f"you can use {green('freshquark')} "
-                "to update the quark-rules later!\n"
-            )
+    except FileNotFoundError:
+
+        print_warning("FileNotFoundError with git clone")
+
+    except subprocess.CalledProcessError as e:
+
+        print_warning(f"CalledProcessError with git clone, error: {e}")
 
     logger()
 
